import * as yargs from 'yargs';
import { CreateWorkspaceOptions } from '../src/create-workspace-options';
import { Preset } from '../src/utils/preset/preset';
interface BaseArguments extends CreateWorkspaceOptions {
    preset: Preset;
}
interface NoneArguments extends BaseArguments {
    stack: 'none';
    workspaceType: 'package-based' | 'integrated' | 'standalone';
    js: boolean;
    appName: string | undefined;
}
interface ReactArguments extends BaseArguments {
    stack: 'react';
    workspaceType: 'standalone' | 'integrated';
    appName: string;
    framework: 'none' | 'next';
    style: string;
    bundler: 'webpack' | 'vite' | 'rspack';
    nextAppDir: boolean;
    e2eTestRunner: 'none' | 'cypress' | 'playwright';
}
interface AngularArguments extends BaseArguments {
    stack: 'angular';
    workspaceType: 'standalone' | 'integrated';
    appName: string;
    style: string;
    routing: boolean;
    standaloneApi: boolean;
    e2eTestRunner: 'none' | 'cypress' | 'playwright';
}
interface VueArguments extends BaseArguments {
    stack: 'vue';
    workspaceType: 'standalone' | 'integrated';
    appName: string;
    style: string;
    e2eTestRunner: 'none' | 'cypress' | 'playwright';
}
interface NodeArguments extends BaseArguments {
    stack: 'node';
    workspaceType: 'standalone' | 'integrated';
    appName: string;
    framework: 'express' | 'fastify' | 'koa' | 'nest';
    docker: boolean;
}
interface UnknownStackArguments extends BaseArguments {
    stack: 'unknown';
}
type Arguments = NoneArguments | ReactArguments | AngularArguments | VueArguments | NodeArguments | UnknownStackArguments;
export declare const commandsObject: yargs.Argv<Arguments>;
export {};
