"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.determinePackageManager = exports.determineDefaultBase = exports.determineCI = exports.determineNxCloud = void 0;
const ab_testing_1 = require("../utils/nx/ab-testing");
const output_1 = require("../utils/output");
const default_base_1 = require("../utils/git/default-base");
const package_manager_1 = require("../utils/package-manager");
const string_utils_1 = require("../utils/string-utils");
const enquirer = require("enquirer");
async function determineNxCloud(parsedArgs) {
    if (parsedArgs.nxCloud === undefined) {
        return enquirer
            .prompt([
            {
                name: 'NxCloud',
                message: ab_testing_1.messages.getPromptMessage('nxCloudCreation'),
                type: 'autocomplete',
                choices: [
                    {
                        name: 'Yes',
                        hint: 'I want faster builds',
                    },
                    {
                        name: 'No',
                    },
                ],
                initial: 'Yes',
            },
        ])
            .then((a) => a.NxCloud === 'Yes');
    }
    else {
        return parsedArgs.nxCloud;
    }
}
exports.determineNxCloud = determineNxCloud;
async function determineCI(parsedArgs, nxCloud) {
    if (!nxCloud) {
        if (parsedArgs.ci) {
            output_1.output.warn({
                title: 'Invalid CI value',
                bodyLines: [
                    `CI option only works when Nx Cloud is enabled.`,
                    `The value provided will be ignored.`,
                ],
            });
        }
        return '';
    }
    if (parsedArgs.ci) {
        return parsedArgs.ci;
    }
    if (parsedArgs.allPrompts) {
        return (enquirer
            .prompt([
            {
                name: 'CI',
                message: `CI workflow file to generate?      `,
                type: 'autocomplete',
                initial: '',
                choices: [
                    { message: 'none', name: '' },
                    { message: 'GitHub Actions', name: 'github' },
                    { message: 'Circle CI', name: 'circleci' },
                    { message: 'Azure DevOps', name: 'azure' },
                ],
            },
        ])
            // enquirer ignores name and value if they are falsy and takes
            // first field that has a truthy value, so wee need to explicitly
            // check for none
            .then((a) => (a.CI !== 'none' ? a.CI : '')));
    }
    return '';
}
exports.determineCI = determineCI;
async function determineDefaultBase(parsedArgs) {
    if (parsedArgs.defaultBase) {
        return Promise.resolve(parsedArgs.defaultBase);
    }
    if (parsedArgs.allPrompts) {
        return enquirer
            .prompt([
            {
                name: 'DefaultBase',
                message: `Main branch name`,
                initial: `main`,
                type: 'input',
            },
        ])
            .then((a) => {
            if (!a.DefaultBase) {
                output_1.output.error({
                    title: 'Invalid branch name',
                    bodyLines: [`Branch name cannot be empty`],
                });
                process.exit(1);
            }
            return a.DefaultBase;
        });
    }
    return Promise.resolve((0, default_base_1.deduceDefaultBase)());
}
exports.determineDefaultBase = determineDefaultBase;
async function determinePackageManager(parsedArgs) {
    const packageManager = parsedArgs.packageManager;
    if (packageManager) {
        if (package_manager_1.packageManagerList.includes(packageManager)) {
            return Promise.resolve(packageManager);
        }
        output_1.output.error({
            title: 'Invalid package manager',
            bodyLines: [
                `Package manager must be one of ${(0, string_utils_1.stringifyCollection)([
                    ...package_manager_1.packageManagerList,
                ])}`,
            ],
        });
        process.exit(1);
    }
    if (parsedArgs.allPrompts) {
        return enquirer
            .prompt([
            {
                name: 'packageManager',
                message: `Which package manager to use`,
                initial: 'npm',
                type: 'autocomplete',
                choices: [
                    { name: 'npm', message: 'NPM' },
                    { name: 'yarn', message: 'Yarn' },
                    { name: 'pnpm', message: 'PNPM' },
                ],
            },
        ])
            .then((a) => a.packageManager);
    }
    return Promise.resolve((0, package_manager_1.detectInvokedPackageManager)());
}
exports.determinePackageManager = determinePackageManager;
