"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupCI = void 0;
const ora = require("ora");
const child_process_utils_1 = require("../child-process-utils");
const error_utils_1 = require("../error-utils");
const output_1 = require("../output");
const package_manager_1 = require("../package-manager");
async function setupCI(directory, ci, packageManager, nxCloudSuccessfullyInstalled) {
    if (!nxCloudSuccessfullyInstalled) {
        output_1.output.error({
            title: `CI workflow generation skipped`,
            bodyLines: [
                `Nx Cloud was not installed`,
                `The autogenerated CI workflow requires Nx Cloud to be set-up.`,
            ],
        });
    }
    const ciSpinner = ora(`Generating CI workflow`).start();
    try {
        const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
        const res = await (0, child_process_utils_1.execAndWait)(`${pmc.exec} nx g @nx/workspace:ci-workflow --ci=${ci}`, directory);
        ciSpinner.succeed('CI workflow has been generated successfully');
        return res;
    }
    catch (e) {
        ciSpinner.fail();
        if (e instanceof Error) {
            output_1.output.error({
                title: `Failed to generate CI workflow`,
                bodyLines: (0, error_utils_1.mapErrorToBodyLines)(e),
            });
        }
        else {
            console.error(e);
        }
        process.exit(1);
    }
    finally {
        ciSpinner.stop();
    }
}
exports.setupCI = setupCI;
