"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.printNxCloudSuccessMessage = exports.setupNxCloud = void 0;
const ora = require("ora");
const child_process_utils_1 = require("../child-process-utils");
const output_1 = require("../output");
const package_manager_1 = require("../package-manager");
const error_utils_1 = require("../error-utils");
async function setupNxCloud(directory, packageManager) {
    const nxCloudSpinner = ora(`Setting up NxCloud`).start();
    try {
        const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
        const res = await (0, child_process_utils_1.execAndWait)(`${pmc.exec} nx g nx-cloud:init --no-analytics --installationSource=create-nx-workspace`, directory);
        nxCloudSpinner.succeed('NxCloud has been set up successfully');
        return res;
    }
    catch (e) {
        nxCloudSpinner.fail();
        if (e instanceof Error) {
            output_1.output.error({
                title: `Failed to setup NxCloud`,
                bodyLines: (0, error_utils_1.mapErrorToBodyLines)(e),
            });
        }
        else {
            console.error(e);
        }
        process.exit(1);
    }
    finally {
        nxCloudSpinner.stop();
    }
}
exports.setupNxCloud = setupNxCloud;
function printNxCloudSuccessMessage(nxCloudOut) {
    const bodyLines = nxCloudOut
        .split('Distributed caching via Nx Cloud has been enabled')[1]
        .trim();
    output_1.output.note({
        title: `Distributed caching via Nx Cloud has been enabled`,
        bodyLines: bodyLines.split('\n').map((r) => r.trim()),
    });
}
exports.printNxCloudSuccessMessage = printNxCloudSuccessMessage;
